"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findObjectExpressionProperty = findObjectExpressionProperty;
exports.getStringNodeValue = getStringNodeValue;
exports.getTemplateLiteralStringValue = getTemplateLiteralStringValue;
exports.findJSXAttribute = findJSXAttribute;

function findObjectExpressionProperty(node, key) {
  return node.properties.find(property => property.type === 'Property' && property.key.type === 'Identifier' && property.key.name === key);
}

function getStringNodeValue(node) {
  if (node.type === 'Literal') {
    return {
      value: node.value,
      loc: node.loc
    };
  }

  if (node.type === 'TemplateLiteral') {
    return getTemplateLiteralStringValue(node);
  }

  return null;
}

function getTemplateLiteralStringValue(literalNode) {
  const [templateElem] = literalNode.quasis;
  return templateElem ? {
    value: templateElem.value.raw,
    loc: templateElem.loc
  } : null;
}

function findJSXAttribute(node, name) {
  return node.attributes.find(attr => attr.type === 'JSXAttribute' && attr.name.name === name);
}